==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgsBuilder internal constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("oygdjmxmnhhabxjo")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("bdwyaqjxqjrehvtk")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("gkuiuxyitrhkgheu")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("sqqbgirksedgijax")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("ntpimcdnwhowqgoq")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("swkiymjpgppnrfnj")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs =
        SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgsBuilder internal constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("xmmegghgfrnpixce")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("pqtnjirgneakqydn")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("jpbygjmsryrydbhr")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("shrxkcmsmbsmcogo")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("nptfejkgehaslkyv")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("jlcsqkoqwqnrxjes")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs =
        SpaceSpaceSettingsKernelGatewayAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}
